@@ -1,7 +1,6 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-""" mtimeAdapter that adapt IPersistent interface to
-    IMTime interface
+""" mtimeAdapter class that adapt IPersistent to IMTime
 
 $Id: product.py 12897 2007-11-10 15:32:08Z cray $
 """
@@ -33,4 +32,3 @@ class mtimeAdapter(object):
     def strftime(self,format=u"%Y-%m-%d %H:%M:%S") :
         """ Return datetime as string using format argument """
         return time.strftime(format,time.localtime(self.mtime))
-        
\ No newline at end of file
