@@ -2,11 +2,11 @@
 #######################################################################
 """ Any Interface Adapter to IPager Interface
 
-$Id: pageradapter.py 51874 2008-10-20 17:22:49Z cray $
+$Id: pageradapter.py 52534 2009-02-11 07:21:10Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51874 $"
+__version__ = "$Revision: 52534 $"
 
 from zope.interface import implements,Interface
 from zope.component import adapts
@@ -38,16 +38,18 @@ class PagerAdapter(object):
     def setPagerParameters(self,revert=None,orphan=None,size=None,context=None) :
         if context :
             self._absolute_url = absoluteURL(context,self.request)
+
+        try :            
+            IRegistry(self.context).export(self,'orphan','size','revert')
+        except TypeError :
+            pass
+
         if revert :
             self.revert = revert 
         if orphan :
             self.orphan = orphan 
         if size :
             self.size = size 
-        try :            
-            IRegistry(self.context).export(self,'orphan','size','revert')
-        except TypeError :
-            pass
 
     def getOb(self,key) :
         return self.context[key]
@@ -98,14 +100,14 @@ class PagerAdapter(object):
         try :    
             return self._before < self.index
         except Exception,msg :
-            print "RRRR",msg            
+            print "Invalid index",msg            
             
         try :
             self._before
         except IndexError :
             return False
         except Exception,msg:
-            print "qq1",msg
+            print "Invalid Index",msg
         else :
             return True                        
 
