@@ -5,7 +5,7 @@
 
 $Id: product.py 12897 2007-11-10 15:32:08Z cray $
 """
-__author__  = "Yegor Shershnev"
+__author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
